@@ -3,8 +3,8 @@
 #'Extract rasters for spatially buffered and temporally dynamic explanatory variables at each
 #'projection date using Google Earth Engine.
 #'@param dates a character string, vector of dates in format "YYYY-MM-DD".
-#'@param spatial.ext the spatial extent for the extracted raster. Object from which extent can be
-#'  extracted of class `Extent`, `RasterLayer`,`SpatialPolygonsDataFrame`, `sf` or `polygon` or
+#'@param spatial.ext the spatial extent for the extracted raster. Object from which extent
+#'  can be extracted of class `SpatExtent`, `SpatRaster`, `sf` polygon or
 #'  numeric vector listing xmin, xmax, ymin and ymax in order.
 #'@param datasetname a character string, the Google Earth Engine dataset to extract data from.
 #'@param bandname a character string, the Google Earth Engine dataset bandname to extract data for.
@@ -62,7 +62,7 @@
 #'
 #'  # Spatial dimension
 #'
-#'  Using the `focal` function in `raster` R package (Hijmans et al., 2015), `GEE.math.fun` is
+#'  Using the `focal` function in `terra` R package (Hijmans et al., 2022), `GEE.math.fun` is
 #'  calculated across the spatial buffer area from each cell in `spatial.ext`. The spatial buffer
 #'  area used is defined by `moving.window matrix`, which dictates the neighbourhood of cells
 #'  surrounding each cell in `spatial.ext` to include in the calculation.
@@ -90,8 +90,8 @@
 #'
 #'  # Aggregation factor
 #'
-#'  `agg.factor` given represents the factor to aggregate `RasterLayer` data with function
-#'  `aggregate` in `raster` R package (Hijmans et al., 2015). Aggregation uses the `GEE.math.fun` as
+#'  `agg.factor` given represents the factor to aggregate `SpatRaster` data with function
+#'  `aggregate` in `terra` R package (Hijmans et al., 2022). Aggregation uses the `GEE.math.fun` as
 #'  the function. Following aggregation spatial buffering using the moving window matrix occurs.
 #'  This is included to minimise computing time if data are of high spatial resolution and a large
 #'  spatial buffer is needed. Ensure to calculate `get_moving_window()` with the spatial resolution
@@ -158,9 +158,8 @@
 #'  D'Agostino McGowan L., and Bryan J., 2022. googledrive: An Interface to Google Drive.
 #'  <https://googledrive.tidyverse.org>, <https://github.com/tidyverse/googledrive>.
 #'
-#'  Hijmans, R. J., Van Etten, J., Cheng, J., Mattiuzzi, M., Sumner, M., Greenberg, J. A.,
-#'  Lamigueiro, O. P., Bevan, A., Racine, E. B. & Shortridge, A. 2015. Package ‘raster’. R package,
-#'  734.
+#'Hijmans, R.J., Bivand, R., Forner, K., Ooms, J., Pebesma, E. and Sumner, M.D.,
+#'2022. Package 'terra'. Maintainer: Vienna, Austria.
 #'@return Returns details of successful explanatory variable raster extractions for each projection
 #'  date.
 #'@export
@@ -458,9 +457,9 @@ extract_buffered_raster <- function(dates,
 
        check_file <- paste0(varname, "_", date1, ".tif")
 
-        file_list <- file_list[grep(check_file, file_list)]
+        file_list_filt <- file_list[grep(check_file, file_list)]
 
-        if (!length(file_list) == 0) {
+        if (!length(file_list_filt) == 0) {
           next()
         }
         }
@@ -492,7 +491,7 @@ extract_buffered_raster <- function(dates,
         path = pathforthisfile,
         overwrite = TRUE
       )
-      raster <- raster::raster(pathforthisfile) # Import raster from temp
+      raster <- terra::rast(pathforthisfile) # Import raster from temp
 
       # Delete unprocessed raster from Google Drive.
       googledrive::drive_rm(paste0(varname, "_", date1, "_unprocessed.tif"))
@@ -559,14 +558,14 @@ extract_buffered_raster <- function(dates,
         }
 
         if(!missing(agg.factor)) {
-          rast <- raster::aggregate(rast, agg.factor, fun = math.fun, na.rm = TRUE)
+          rast <- terra::aggregate(rast, agg.factor, fun = math.fun, na.rm = TRUE)
         }
         # If data are categorical then moving.window.matrix with weights = 1
         moving.window.matrix[1:nrow(moving.window.matrix),
                              1:ncol(moving.window.matrix)] <- 1
 
         # Calculate math.fun function across moving.window.matrix for the raster
-        focalraster <- raster::focal(rast,
+        focalraster <- terra::focal(rast,
                                      moving.window.matrix,
                                      fun = math.fun,
                                      na.rm = TRUE)
@@ -576,11 +575,11 @@ extract_buffered_raster <- function(dates,
       if (missing(categories)) {
 
         if (!missing(agg.factor)) {
-          raster <- raster::aggregate(raster, agg.factor, fun = math.fun, na.rm = TRUE)
+          raster <- terra::aggregate(raster, agg.factor, fun = math.fun, na.rm = TRUE)
         }
 
         # Calculate math.fun function across moving.window.matrix for the raster
-        focalraster <- raster::focal(raster, moving.window.matrix, fun = math.fun)
+        focalraster <- terra::focal(raster, moving.window.matrix, fun = math.fun)
       }
 
       if (!missing(save.directory)) {
@@ -588,8 +587,7 @@ extract_buffered_raster <- function(dates,
       }
 
       # Write spatially buffered raster to temp dir or save dir
-      raster::writeRaster(focalraster, pathforthisfile, overwrite = TRUE)
-
+      terra::writeRaster(focalraster, pathforthisfile, overwrite = TRUE)
 
       if(!missing(save.drive.folder)){
       # Check folder exists in  Google Drive
@@ -655,7 +653,7 @@ extract_buffered_raster <- function(dates,
       if (!missing(save.directory)) {
 
         lapply(dates.in.period[2:length(dates.in.period)], FUN = function(savefile)
-          raster::writeRaster(focalraster,
+          terra::writeRaster(focalraster,
                               paste0(save.directory, "/", varname, "_", savefile, ".tif"),
                               overwrite = TRUE
             )
@@ -665,7 +663,7 @@ extract_buffered_raster <- function(dates,
 
 
       # Record successful download and iterate onto next date
-      completed.list <- rbind(completed.list, paste0(varname, "_", dates.in.period))
+      completed.list <- c(completed.list, paste0(varname, "_", dates.in.period))
       message(paste0("Completed: ",varname, "_", dates.in.period))
     }
 
